/***********************************************************************************************************************************
Azure Storage File Write
***********************************************************************************************************************************/
#ifndef STORAGE_AZURE_WRITE_H
#define STORAGE_AZURE_WRITE_H

#include "storage/azure/storage.intern.h"
#include "storage/write.h"

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
FN_EXTERN StorageWrite *storageWriteAzureNew(StorageAzure *storage, const String *name, uint64_t fileId, size_t blockSize);

#endif
